/**
 * 获得base64
 * 
 * @param {Object}
 *            obj
 * @param {Number}
 *            [obj.width] 图片需要压缩的宽度，高度会跟随调整
 * @param {Number}
 *            [obj.quality=0.8] 压缩质量，不压缩为1
 * @param {Function}
 *            [obj.before(this, blob, file)] 处理前函数,this指向的是input:file
 * @param {Function}
 *            obj.success(obj) 处理后函数
 * @example
 * 
 */

$.fn.localResizeIMG = function(obj) {
//	this.live('change', function() {
		var file = obj.file;//this.files[0];//
		if (window.navigator.userAgent.indexOf("Chrome") >= 1
				|| window.navigator.userAgent.indexOf("Safari") >= 1) {
			var blob = window.webkitURL.createObjectURL(file);
		} else {
			var blob = window.URL.createObjectURL(file);
		}

		// 执行前函数
		if ($.isFunction(obj.before)) {
			obj.before(this, blob, file)
		}

		_create(blob, file);
		this.value = ''; // 清空临时数据
//	});

	/**
	 * 生成base64
	 * 
	 * @param blob
	 *            通过file获得的二进制
	 */
	function _create(blob, file) {
		var img = new Image();
		img.src = blob;

		img.onload = function() {
			var that = this;
			// 生成比例
			var w = that.width, h = that.height, scale = w / h;
			if (obj.width < w) {
				w = obj.width;
			}
			h = w / scale;

			var canvas = document.createElement('canvas');
			var ctx = canvas.getContext('2d');//var mt=0;ml=0;
//			var sw=$(window).width()*0.3;
//			var sh=h*sw/w;
			
//			switch(angle.trim()) {
//	        case "8":
//	        	angle = 1;
//	            break;
//	        case "3":
//	        	angle = 2;
//	            break;
//	        case "6":
//	        	angle = 3;
//	            break;
//	        default:
//	        	angle = 0;
//	        	break;
//			}
//			console.log(angle);
			
			$(canvas).attr({width:w,height:h});
			ctx.drawImage(that, 0, 0, w, h);
			
//			switch(angle % 4){
//			case 0:
////				$(canvas).attr({width:w,height:h});
////				ctx.rotate(angle * 90 * Math.PI / 180);
////				ctx.drawImage(that, 0, 0, w, h);
//				if(w>h){
//					ml=(sw-sh)/2;
//				}else{
//					mt=(sh-sw)/2;
//				}
//				break;
//			case 1:
//			case -3:
////				$(canvas).attr({width:h,height:w});
////				ctx.rotate(angle * 90 * Math.PI / 180);
////				ctx.drawImage(that, 0, -1*h, w, h);
//				if(w>h){
//					mt=(sw-sh)/2;//
//				}else{
//					ml=(sh-sw)/2;//
//				}
//				break;
//			case 2:
//			case -2:
////				$(canvas).attr({width:w,height:h});
////				ctx.rotate(angle * 90 * Math.PI / 180);
////				ctx.drawImage(that, -1*w, -1*h, w, h);
//				if(w>h){
//					ml=(sw-sh)/2;
//				}else{
//					mt=(sh-sw)/2;
//				}
//				break;
//			case 3:
//			case -1:
////				$(canvas).attr({width:h,height:w});
////				ctx.rotate(angle * 90 * Math.PI / 180);
////				ctx.drawImage(that, -1*w, 0, w, h);
//				if(w>h){
//					mt=(sw-sh)/2;//
//				}else{
//					ml=(sh-sw)/2;//
//				}
//				break;
//			}
//			console.log(ml + "," + mt);

			/**
			 * 生成base64 兼容修复移动设备需要引入mobileBUGFix.js
			 */
			var base64 = canvas.toDataURL('image/jpeg', obj.quality || 0.8);
			
			// 修复IOS
			if (navigator.userAgent.match(/iphone/i)) {
				var mpImg = new MegaPixImage(img);
				mpImg.render(canvas, {
					maxWidth : w,
					maxHeight : h,
					quality : obj.quality || 0.8,
					orientation : 6
				});
				base64 = canvas.toDataURL('image/jpeg', obj.quality || 0.8);
			}

			// 修复android
			if (navigator.userAgent.match(/Android/i)) {
				var encoder = new JPEGEncoder();
				base64 = encoder.encode(ctx.getImageData(0, 0, w, h),
						obj.quality * 100 || 80);
			}
			
			//
			// 生成结果
			var result = {
				name : file.name,
				blob : blob,
				base64 : base64,
				clearBase64 : base64.substr(base64.indexOf(',') + 1)//,
//				ml : ml,
//				mt : mt
			};

			// 执行后函数
			obj.success(result);
		};
	}
};

// 例子
/*
 * $('input:file').localResizeIMG({ width: 100, quality: 0.1, //before: function
 * (that, blob) {}, success: function (result) { var img = new Image(); img.src =
 * result.base64;
 * 
 * $('body').append(img); console.log(result); } });
 */
